#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x summary-body.py
##    ./summary-body.py
##
## Copyright 2009 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import pynotify
import example

if __name__ == '__main__':
	if not pynotify.init ("summary-body"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# try the summary-body case
	n = pynotify.Notification ("Totem",
				   "This is a superfluous notification")
	n.show ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-incoming-call.py
##    ./sd-example-incoming-call.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import gobject
import example

def action_decline_1 (notification, action):
	if action == "action_decline_1":
		print "Decline"
	else:
		print "That should not have happened (action_decline_1)!"

def action_decline_2 (notification, action):
	if action == "action_decline_2":
		print "\"Can't talk now, what's up?\""
	else:
		print "That should not have happened (action_decline_2)!"

def action_decline_3 (notification, action):
	if action == "action_decline_3":
		print "\"I call you back.\""
	else:
		print "That should not have happened (action_decline_3)!"

def action_decline_4 (notification, action):
	if action == "action_decline_4":
		print "Send custom message..."
	else:
		print "That should not have happened (action_decline_4)!"

def action_accept (notification, action):
	if action == "action_accept":
		print "Accepting call"
	else:
		print "That should not have happened (action_accept)!"

def pushNotification (title, body, icon):
	n = pynotify.Notification (title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("action_accept",    "Accept",                         action_accept);
	n.add_action ("action_decline_1", "Decline",                        action_decline_1);
	n.add_action ("action_decline_2", "\"Can't talk now, what's up?\"", action_decline_2);
	n.add_action ("action_decline_3", "\"I call you back.\"",           action_decline_3);
	n.add_action ("action_decline_4", "Send custom message...",         action_decline_4);

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");
	n.set_hint_string ("x-canonical-private-button-tint", "true");
	n.set_hint_string ("x-canonical-secondary-icon", os.getcwd() + "/assets/icon_phone.png");
	n.set_urgency (pynotify.URGENCY_CRITICAL)

	n.show ()
	return n

if __name__ == '__main__':
	if not pynotify.init ("sd-example-incoming-call"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-canonical-snap-decisions']:
		sys.exit (2)

	loop = gobject.MainLoop ()
	n = pushNotification ("Incoming call",
	                      "Frank Zappa\n+44 (0)7736 027340",
	                      os.getcwd() + "/assets/avatar4.jpg")
	n.connect ("closed", example.closedHandler, loop)

	loop.run ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-user-auth.py
##    ./sd-example-user-auth.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys

from gi.repository import Gio, GLib, Notify

APPLICATION_ID = 'com.canonical.snapdecisions'
PASSWORD_MENU_PATH = '/com/canonical/snapdecisions/password'
PASSWORD_ACTION_PATH = '/com/canonical/snapdecisions/password'

def quit_callback(notification, loop):
	global connection
	global exported_action_group_id
	global exported_menu_model_id

	connection.unexport_action_group (exported_action_group_id)
	connection.unexport_menu_model (exported_menu_model_id)

	loop.quit()

def cancel (notification, action, data):
	if action == "cancel":
		print "Cancel"
	else:
		print "That should not have happened (cancel)!"

def connect (notification, action, data):
	if action == "connect":
		global login
		print "login entered: " + login
		global password
		print "password entered: " + password
	else:
		print "That should not have happened (connect)!"

def login_changed (action, variant):
	global login
	login = variant.get_string();

def password_changed (action, variant):
	global password
	password = variant.get_string();

def bus_acquired(bus, name):
	# menu
	menu = Gio.Menu();

	login_item = Gio.MenuItem.new ("Login name:", "notifications.login");
	login_item.set_attribute_value ("x-canonical-type", GLib.Variant.new_string("com.canonical.snapdecision.textfield"));
	login_item.set_attribute_value ('x-echo-mode-password', GLib.Variant.new_boolean(False))
	menu.append_item (login_item);

	password_item = Gio.MenuItem.new ("Password:", "notifications.password");
	password_item.set_attribute_value ("x-canonical-type", GLib.Variant.new_string("com.canonical.snapdecision.textfield"));
	password_item.set_attribute_value ('x-echo-mode-password', GLib.Variant.new_boolean(True))
	menu.append_item (password_item);

	# actions
	actions = Gio.SimpleActionGroup.new();
	password_action = Gio.SimpleAction.new_stateful("password", GLib.VariantType.new("s"), GLib.Variant.new_string(""));
	password_action.connect ("change-state", password_changed);
	actions.insert (password_action);
	login_action = Gio.SimpleAction.new_stateful("login", GLib.VariantType.new("s"), GLib.Variant.new_string(""));
	login_action.connect ("change-state", login_changed);
	actions.insert (login_action);

	global connection
	connection = bus

	global exported_action_group_id
	exported_action_group_id = connection.export_action_group(PASSWORD_ACTION_PATH, actions)

	global exported_menu_model_id
	exported_menu_model_id = connection.export_menu_model(PASSWORD_MENU_PATH, menu)

def pushNotification (title, body, icon):
	n = Notify.Notification.new(title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("connect", "Connect", connect, None, None);
	n.add_action ("cancel", "Cancel", cancel, None, None);

	# create the menu-model
	menu_model_actions = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}")); 
	entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("notifications"),
			GLib.Variant.new_variant(GLib.Variant.new_string(PASSWORD_ACTION_PATH)));
	menu_model_actions.add_value (entry);

	menu_model_paths = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}"));
	entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("busName"),
			GLib.Variant.new_variant(GLib.Variant.new_string(APPLICATION_ID)));
	menu_model_paths.add_value (entry);
	entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("menuPath"),
			GLib.Variant.new_variant(GLib.Variant.new_string(PASSWORD_MENU_PATH)));
	menu_model_paths.add_value (entry);
	entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("actions"),
			GLib.Variant.new_variant(menu_model_actions.end()));
	menu_model_paths.add_value (entry);

	n.set_hint ("x-canonical-private-menu-model", menu_model_paths.end ());

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");
	n.set_hint_string ("x-canonical-private-button-tint", "true");
	n.set_hint_string ("x-canonical-non-shaped-icon", "true"); 

	Gio.bus_own_name(Gio.BusType.SESSION, APPLICATION_ID, 0, bus_acquired, None, None)

	return n

if __name__ == '__main__':
	if not Notify.init("sd-example-user-auth"):
		sys.exit (1)

	connection = None
	exported_menu_model_id = 0
	exported_action_group_id = 0
	login = ""
	password = ""

	loop = GLib.MainLoop()
	n = pushNotification ("Connect to \"linksys\"", "", "image://theme/nm-signal-100")
	n.connect('closed', quit_callback, loop)
	n.show ()

	loop.run()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-incoming-call-canceled.py
##    ./sd-example-incoming-call-canceled.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import gobject
import example

def action_decline_1 (notification, action):
	if action == "action_decline_1":
		print "Hang up"
	else:
		print "That should not have happened (action_decline_1)!"

def action_decline_2 (notification, action):
	if action == "action_decline_2":
		print "\"Dude, my wife is here!\""
	else:
		print "That should not have happened (action_decline_2)!"

def action_decline_3 (notification, action):
	if action == "action_decline_3":
		print "\"I'm sleeping.\""
	else:
		print "That should not have happened (action_decline_3)!"

def action_decline_4 (notification, action):
	if action == "action_decline_4":
		print "\"No time... I'm riding!\""
	else:
		print "That should not have happened (action_decline_4)!"

def action_decline_5 (notification, action):
	if action == "action_decline_5":
		print "Send SMS..."
	else:
		print "That should not have happened (action_decline_5)!"

def action_accept (notification, action):
	if action == "action_accept":
		print "Picking up the phone"
	else:
		print "That should not have happened (action_accept)!"

def pushNotification (title, body, icon):
	n = pynotify.Notification (title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("action_accept",    "Pick up",                    action_accept);
	n.add_action ("action_decline_1", "Hang up",                    action_decline_1);
	#n.add_action ("action_decline_2", "\"Dude, my wife is here!\"", action_decline_2);
	#n.add_action ("action_decline_3", "\"I'm sleeping.\"",          action_decline_3);
	#n.add_action ("action_decline_4", "\"No time... I'm riding!\"", action_decline_4);
	#n.add_action ("action_decline_5", "Send SMS...",                action_decline_5);

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");
	n.set_hint_string ("x-canonical-secondary-icon", os.getcwd() + "/assets/icon_phone.png");

	# set the button-tint hint so that the right/positive button is tinted and
	# not using the stock clear-color
	n.set_hint_string ("x-canonical-private-button-tint", "true");
	n.set_urgency (pynotify.URGENCY_CRITICAL)

	n.show ()
	return n

def hung_up_timeout (notification):
	print "Application is hanging up now"
	notification.close ()

if __name__ == '__main__':
	if not pynotify.init ("sd-example-incoming-call-canceled"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-canonical-private-button-tint'] and not example.capabilities['x-canonical-snap-decisions']:
		sys.exit (2)

	loop = gobject.MainLoop ()
	n = pushNotification ("Incoming call",
	                      "Bro Coly\n+1 (0)555-27439",
	                      os.getcwd() + "/assets/avatar3.jpg")
	n.connect ("closed", example.closedHandler, loop)

	# simulate caller hanging up before phone is picked up
	timeout_id = gobject.timeout_add (3000, hung_up_timeout, n)

	loop.run ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x sd-example-much-body-text.py
##    ./sd-example-much-body-text.py
##
## Copyright 2012 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import gobject
import example

def action_decline (notification, action):
	if action == "decline_id":
		print "Declined"
	else:
		print "That should not have happened (action_decline)!"

def action_ok (notification, action):
	if action == "ok_id":
		print "Ok"
	else:
		print "That should not have happened (action_ok)!"

def pushNotification (title, body, icon):
	n = pynotify.Notification (title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("ok_id",      "Ok",     action_ok);
	n.add_action ("decline_id", "Cancel", action_decline);

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");

	# set the button-tint hint so that the right/positive button is tinted and
	# not using the stock clear-color
	n.set_hint_string ("x-canonical-private-button-tint", "true");
	n.set_hint_string ("x-canonical-non-shaped-icon", "true");

	n.show ()
	return n

if __name__ == '__main__':
	if not pynotify.init ("sd-example-much-body-text"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-canonical-private-button-tint'] and not example.capabilities['x-canonical-snap-decisions']:
		sys.exit (2)

	loop = gobject.MainLoop ()
	n = pushNotification ("Uses much text",
                          "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.",
						  "messages")
	n.connect ("closed", example.closedHandler, loop)

	loop.run ()
